@@ -5,9 +5,9 @@ from django.contrib.gis.gdal import HAS_GDAL
 from django.contrib.gis.utils.wkt import precision_wkt  # NOQA
 
 if HAS_GDAL:
-    from django.contrib.gis.utils.ogrinfo import ogrinfo, sample  # NOQA
+    from django.contrib.gis.utils.ogrinfo import ogrinfo  # NOQA
     from django.contrib.gis.utils.ogrinspect import mapping, ogrinspect  # NOQA
-    from django.contrib.gis.utils.srs import add_postgis_srs, add_srs_entry  # NOQA
+    from django.contrib.gis.utils.srs import add_srs_entry  # NOQA
     from django.core.exceptions import ImproperlyConfigured
     try:
         # LayerMapping requires DJANGO_SETTINGS_MODULE to be set,
